+ [[label]] Click here to download latest version Download latest version from here Click here to download latest version Download latest version from here Click here to download latest version Download latest version from here
+
\ No newline at end of file
+
From 18305dee4f8e5ecc3b1e3c6ff868712fd6575742 Mon Sep 17 00:00:00 2001
From: pewgeuges <73141620+pewgeuges@users.noreply.github.com>
Date: Sun, 8 Nov 2020 21:52:49 +0000
Subject: [PATCH 14/27] development version 2.1.1d0: restore jQuery UI from
CDNJS / Cloudflare for Forum User
git-svn-id: https://plugins.svn.wordpress.org/footnotes/trunk@2414868 b8457f37-d9ea-0310-8a92-e5e31aec5664
---
class/init.php | 34 +++++++++++++++++-----------------
css/public.css | 4 ++--
footnotes.php | 2 +-
readme.txt | 3 +++
4 files changed, 23 insertions(+), 20 deletions(-)
diff --git a/class/init.php b/class/init.php
index 35ca2d5..b08f45c 100644
--- a/class/init.php
+++ b/class/init.php
@@ -122,29 +122,29 @@ class MCI_Footnotes {
// add the jQuery plugin registered by WordPress
wp_enqueue_script( 'jquery' );
- // Add jQuery Tools:
- wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));
-
- // Add the jQuery UI libraries registered by WordPress:
- // 'no need to enqueue -core, because dependencies are set'
- // Source:
+
[[label-readon]]
+ [[readon]]
+ (Quick fix, will be moved to its place.)
+
-[[label-name]]
[[name]]
@@ -13,4 +18,4 @@
[[position]]
+ [[arrow-index]][[arrow-index]]
Date: Wed, 11 Nov 2020 13:24:25 +0000
Subject: [PATCH 16/27] development version 2.1.1d2 fix enqueuing in response
to user
git-svn-id: https://plugins.svn.wordpress.org/footnotes/trunk@2416626 b8457f37-d9ea-0310-8a92-e5e31aec5664
---
class/init.php | 67 +++++++++++++++++++++++-------------------------
css/public.css | 4 +--
css/settings.css | 4 +--
footnotes.php | 2 +-
readme.txt | 3 +++
5 files changed, 40 insertions(+), 40 deletions(-)
diff --git a/class/init.php b/class/init.php
index f0cb3ec..cb47e90 100644
--- a/class/init.php
+++ b/class/init.php
@@ -1,7 +1,7 @@
initializeDashboard();
// initialize the Plugin Task
$this->initializeTask();
-
+
// Register all Public Stylesheets and Scripts
add_action('init', array($this, 'registerPublic'));
// Enqueue all Public Stylesheets and Scripts
@@ -68,11 +68,11 @@ class MCI_Footnotes {
*
* @author Stefan Herndler
* @since 1.5.0
- *
+ *
* Edited for 1.6.5: replaced deprecated function create_function()
- *
+ *
* Contributed by Felipe Lavín Z. Thankfully acknowledged.
- *
+ *
* create_function() was deprecated in PHP 7.2:
* [[label-enable]]
[[enable]]
+
[[label-alternative]]
+ [[alternative]]
+
-
\ No newline at end of file
+
diff --git a/templates/public/footnote-alternative.html b/templates/public/footnote-alternative.html
new file mode 100644
index 0000000..d94aa22
--- /dev/null
+++ b/templates/public/footnote-alternative.html
@@ -0,0 +1,16 @@
+[[before]][[index]][[after]][[text]]
diff --git a/templates/public/footnote.html b/templates/public/footnote.html
index 421a5df..b146176 100755
--- a/templates/public/footnote.html
+++ b/templates/public/footnote.html
@@ -1,14 +1,13 @@
-[[before]][[index]][[after]]
-[[text]][[text]]
From 9d0044a35a2f6d0e0c9295284c5b0869b34ef2da Mon Sep 17 00:00:00 2001
From: pewgeuges <73141620+pewgeuges@users.noreply.github.com>
Date: Thu, 12 Nov 2020 04:46:44 +0000
Subject: [PATCH 18/27] development version 2.1.1d4: redacted (commented out)
jQuery.browser function use in jquery.tools.min.js, updating for the Forum in
response to user
git-svn-id: https://plugins.svn.wordpress.org/footnotes/trunk@2416961 b8457f37-d9ea-0310-8a92-e5e31aec5664
---
class/init.php | 2 +-
css/public.css | 4 ++--
css/settings.css | 4 ++--
footnotes.php | 2 +-
js/jquery.tools.min.js | 42 +++++++++++++++++++++++++----------
readme.txt | 4 ++++
templates/public/tooltip.html | 1 +
7 files changed, 41 insertions(+), 18 deletions(-)
diff --git a/class/init.php b/class/init.php
index 76d346a..3f67ff7 100644
--- a/class/init.php
+++ b/class/init.php
@@ -151,7 +151,7 @@ class MCI_Footnotes {
'mci-footnotes-css-public',
plugins_url('../css/public.css', __FILE__),
'',
- '2.1.1d3'
+ '2.1.1d4'
);
}
diff --git a/css/public.css b/css/public.css
index 8f14bec..d45198f 100755
--- a/css/public.css
+++ b/css/public.css
@@ -4,9 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.1.1d3
+ * Version: 2.1.1d4
*
- * Last modified: 2020-11-11T2146+0100
+ * Last modified: 2020-11-12T0539+0100
*/
diff --git a/css/settings.css b/css/settings.css
index b6c0cac..55a9800 100755
--- a/css/settings.css
+++ b/css/settings.css
@@ -4,9 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.1.1d3
+ * Version: 2.1.1d4
*
- * Last modified: 2020-11-11T2145+0100
+ * Last modified: 2020-11-12T0539+0100
*/
diff --git a/footnotes.php b/footnotes.php
index 2a8c5ec..834fc74 100755
--- a/footnotes.php
+++ b/footnotes.php
@@ -4,7 +4,7 @@
Plugin URI: https://wordpress.org/plugins/footnotes/
Description: time to bring footnotes to your website! footnotes are known from offline publishing and everybody takes them for granted when reading a magazine.
Author: Mark Cheret
- Version: 2.1.1d3
+ Version: 2.1.1d4
Author URI: http://cheret.de/plugins/footnotes-2/
Text Domain: footnotes
Domain Path: /languages
diff --git a/js/jquery.tools.min.js b/js/jquery.tools.min.js
index 885fb3b..d34b477 100644
--- a/js/jquery.tools.min.js
+++ b/js/jquery.tools.min.js
@@ -21,20 +21,40 @@
*
* -----
*
- * Added jQueryUI and checks whether a.browser exists
+ * Added jQueryUI and checks whether jQuery.browser exists
* Following @vonpiernik [[label-activate-excerpt]]
[[activate-excerpt]]
@@ -53,4 +57,4 @@
[[box-shadow-color]] [[notice-box-shadow-color]]
Flash version " + d.version + " or greater is required
" + (i[0] > 0 ? "Your version is " + i : "You have no flash plugin installed") + "
" + (c.tagName == "A" ? "Flash version " + d.version + " or greater is required
" + (i[0] > 0 ? "Your version is " + i : "You have no flash plugin installed") + "
" + (c.tagName == "A" ? "Flash version "+d.version+" or greater is required
"+(i[0]>0?"Your version is "+i:"You have no flash plugin installed")+"
"+("A"==c.tagName?"
+
diff --git a/templates/public/reference-container-body.html b/templates/public/reference-container-body.html
index eedad5c..359c6cd 100755
--- a/templates/public/reference-container-body.html
+++ b/templates/public/reference-container-body.html
@@ -1,11 +1,12 @@
[[backlinks]]
+ [[text]]
+
[[arrow-index]][[arrow-index]]
Date: Mon, 16 Nov 2020 13:28:41 +0000
Subject: [PATCH 22/27] development 2.1.1d8 commented out all script loads to
check if it fixes a theme incompatibility
git-svn-id: https://plugins.svn.wordpress.org/footnotes/trunk@2419373 b8457f37-d9ea-0310-8a92-e5e31aec5664
---
class/init.php | 24 +++++++++----------
css/public.css | 4 ++--
css/settings.css | 4 ++--
footnotes.php | 2 +-
readme.txt | 3 +++
.../reference-container-body-3column.html | 19 +++++++++++++++
.../reference-container-body-switch.html | 14 +++++++++++
7 files changed, 53 insertions(+), 17 deletions(-)
create mode 100644 templates/public/reference-container-body-3column.html
create mode 100644 templates/public/reference-container-body-switch.html
diff --git a/class/init.php b/class/init.php
index aac8a03..7b28f0e 100644
--- a/class/init.php
+++ b/class/init.php
@@ -119,17 +119,17 @@ class MCI_Footnotes {
//### SCRIPTS
- // enqueue the jQuery plugin registered by WordPress:
- wp_enqueue_script( 'jquery' );
-
- // enqueue jQuery UI libraries registered by WordPress, needed for tooltips:
- wp_enqueue_script( 'jquery-ui-core' );
- wp_enqueue_script( 'jquery-ui-widget' );
- wp_enqueue_script( 'jquery-ui-position' );
- wp_enqueue_script( 'jquery-ui-tooltip' );
-
- // enqueue jQuery Tools:
- wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));
+// // enqueue the jQuery plugin registered by WordPress:
+// wp_enqueue_script( 'jquery' );
+//
+// // enqueue jQuery UI libraries registered by WordPress, needed for tooltips:
+// wp_enqueue_script( 'jquery-ui-core' );
+// wp_enqueue_script( 'jquery-ui-widget' );
+// wp_enqueue_script( 'jquery-ui-position' );
+// wp_enqueue_script( 'jquery-ui-tooltip' );
+//
+// // enqueue jQuery Tools:
+// wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));
// Alternatively, fetch jQuery UI from cdnjs.cloudflare.com:
@@ -151,7 +151,7 @@ class MCI_Footnotes {
'mci-footnotes-css-public',
plugins_url('../css/public.css', __FILE__),
'',
- '2.1.1d7'
+ '2.1.1d8'
);
}
diff --git a/css/public.css b/css/public.css
index 869b135..ce532b0 100755
--- a/css/public.css
+++ b/css/public.css
@@ -4,9 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.1.1d7
+ * Version: 2.1.1d8
*
- * Last modified: 2020-11-14T2229+0100
+ * Last modified: 2020-11-16T1424+0100
*/
diff --git a/css/settings.css b/css/settings.css
index efb0bc9..ebaf820 100755
--- a/css/settings.css
+++ b/css/settings.css
@@ -4,9 +4,9 @@
* Created-Date: 15.05.14
* Created-Time: 16:21
* Since: 1.0
- * Version: 2.1.1d7
+ * Version: 2.1.1d8
*
- * Last modified: 2020-11-14T2228+0100
+ * Last modified: 2020-11-16T1423+0100
*/
diff --git a/footnotes.php b/footnotes.php
index 5a34f7b..0d2ff41 100755
--- a/footnotes.php
+++ b/footnotes.php
@@ -4,7 +4,7 @@
Plugin URI: https://wordpress.org/plugins/footnotes/
Description: time to bring footnotes to your website! footnotes are known from offline publishing and everybody takes them for granted when reading a magazine.
Author: Mark Cheret
- Version: 2.1.1d7
+ Version: 2.1.1d8
Author URI: http://cheret.de/plugins/footnotes-2/
Text Domain: footnotes
Domain Path: /languages
diff --git a/readme.txt b/readme.txt
index e7e721e..565cfd7 100755
--- a/readme.txt
+++ b/readme.txt
@@ -80,6 +80,9 @@ Visit this swift write-up from a **footnotes** user by the name of **Southwest**
== Changelog ==
+= 2.1.1d8 =
+- Bugfix: Libraries: commented out all script loads to check if it fixes a theme incompatibility
+
= 2.1.1d7 =
- Bugfix: Combining identical footnotes: fixed dead links
diff --git a/templates/public/reference-container-body-3column.html b/templates/public/reference-container-body-3column.html
new file mode 100644
index 0000000..66392e3
--- /dev/null
+++ b/templates/public/reference-container-body-3column.html
@@ -0,0 +1,19 @@
+
+
diff --git a/templates/public/reference-container-body-switch.html b/templates/public/reference-container-body-switch.html
new file mode 100644
index 0000000..33f8e55
--- /dev/null
+++ b/templates/public/reference-container-body-switch.html
@@ -0,0 +1,14 @@
+[[index]]
+ [[arrow]]
+ [[text]]
+
+
diff --git a/class/init.php b/class/init.php
index 7b28f0e..85dafce 100644
--- a/class/init.php
+++ b/class/init.php
@@ -119,29 +119,37 @@ class MCI_Footnotes {
//### SCRIPTS
-// // enqueue the jQuery plugin registered by WordPress:
-// wp_enqueue_script( 'jquery' );
-//
-// // enqueue jQuery UI libraries registered by WordPress, needed for tooltips:
-// wp_enqueue_script( 'jquery-ui-core' );
-// wp_enqueue_script( 'jquery-ui-widget' );
-// wp_enqueue_script( 'jquery-ui-position' );
-// wp_enqueue_script( 'jquery-ui-tooltip' );
-//
-// // enqueue jQuery Tools:
-// wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));
+ // These are only enqueued if the jQuery tooltips are enabled.
+ // If alternative tooltips are enabled, these libraries are not needed.
+ // Scroll animation doesn’t seem to need even jQuery Core or it gets it from elsewhere.
+
+ if (!MCI_Footnotes_Convert::toBool(MCI_Footnotes_Settings::instance()->get(MCI_Footnotes_Settings::C_BOOL_FOOTNOTES_MOUSE_OVER_BOX_ALTERNATIVE))) {
+
+ // enqueue the jQuery plugin registered by WordPress:
+ wp_enqueue_script( 'jquery' );
+
+ // enqueue jQuery UI libraries registered by WordPress, needed for tooltips:
+ wp_enqueue_script( 'jquery-ui-core' );
+ wp_enqueue_script( 'jquery-ui-widget' );
+ wp_enqueue_script( 'jquery-ui-position' );
+ wp_enqueue_script( 'jquery-ui-tooltip' );
+
+ // enqueue jQuery Tools:
+ wp_enqueue_script('mci-footnotes-js-jquery-tools', plugins_url('../js/jquery.tools.min.js', __FILE__));
- // Alternatively, fetch jQuery UI from cdnjs.cloudflare.com:
- // Used to add jQuery UI following @vonpiernik:
- // [[index]].[[arrow]]
+ [[text]]
+
From 3e4453929ad0b5520c0c4de4d9d21531b45bc8e9 Mon Sep 17 00:00:00 2001
From: pewgeuges <73141620+pewgeuges@users.noreply.github.com>
Date: Mon, 16 Nov 2020 20:57:15 +0000
Subject: [PATCH 23/27] development 2.1.1d9 last fixes for evaluation
project-side / user-side
git-svn-id: https://plugins.svn.wordpress.org/footnotes/trunk@2419624 b8457f37-d9ea-0310-8a92-e5e31aec5664
---
class/dashboard/subpage-main.php | 52 ++++--
class/init.php | 52 +++---
class/settings.php | 57 +++++--
class/task.php | 150 +++++++++++-------
css/public.css | 18 ++-
css/settings.css | 4 +-
footnotes.php | 2 +-
readme.txt | 29 ++--
.../dashboard/customize-mouse-over-box.html | 56 ++++---
.../dashboard/customize-superscript.html | 6 +-
.../settings-reference-container.html | 21 ++-
templates/public/footnote-alternative.html | 4 +-
templates/public/footnote.html | 4 +-
.../reference-container-body-3column.html | 4 +-
.../reference-container-body-switch.html | 3 +-
.../public/reference-container-body.html | 5 +-
templates/public/reference-container.html | 7 +-
17 files changed, 308 insertions(+), 166 deletions(-)
diff --git a/class/dashboard/subpage-main.php b/class/dashboard/subpage-main.php
index 645b8a2..40bf24c 100644
--- a/class/dashboard/subpage-main.php
+++ b/class/dashboard/subpage-main.php
@@ -7,8 +7,11 @@
* @since 1.5.0 14.09.14 14:47
*
* Edited for:
- * v2.0.4 2020-11-01T0509+0100
- * v2.1.0 2020-11-08T2148+0100
+ * 2.0.4 2020-11-01T0509+0100
+ * 2.1.0 2020-11-08T2148+0100
+ * 2.1.1 2020-11-16T2152+0100
+ *
+ * Last modified: 2020-11-16T2152+0100
*/
/**
@@ -82,7 +85,7 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
*/
protected function getMetaBoxes() {
return array(
// Change string "%s styling" to "Footnotes styling":
$this->addMetaBox("settings", "styling", __("Footnotes styling", MCI_Footnotes_Config::C_STR_PLUGIN_NAME), "Styling"),
$this->addMetaBox("settings", "reference-container", __("References Container", MCI_Footnotes_Config::C_STR_PLUGIN_NAME), "ReferenceContainer"),
// Leave intact since this is not localized:
@@ -115,20 +118,34 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
"post_end" => __("at the end of the post", MCI_Footnotes_Config::C_STR_PLUGIN_NAME),
"widget" => __("in the widget area", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)
);
+ // options for Yes/No select box:
+ $l_arr_Enabled = array(
+ "yes" => __("Yes", MCI_Footnotes_Config::C_STR_PLUGIN_NAME),
+ "no" => __("No", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)
+ );
// load template file
$l_obj_Template = new MCI_Footnotes_Template(MCI_Footnotes_Template::C_STR_DASHBOARD, "settings-reference-container");
// replace all placeholders
$l_obj_Template->replace(
array(
- "label-readon" => $this->addLabel(MCI_Footnotes_Settings::C_STR_FOOTNOTES_TOOLTIP_READON_LABEL, __("‘Read on’ button label", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
- "readon" => $this->addTextBox(MCI_Footnotes_Settings::C_STR_FOOTNOTES_TOOLTIP_READON_LABEL),
-
"label-name" => $this->addLabel(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_NAME, __("References label", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
"name" => $this->addTextBox(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_NAME),
"label-collapse" => $this->addLabel(MCI_Footnotes_Settings::C_BOOL_REFERENCE_CONTAINER_COLLAPSE, __("Collapse references by default", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
- "collapse" => $this->addCheckbox(MCI_Footnotes_Settings::C_BOOL_REFERENCE_CONTAINER_COLLAPSE),
+ "collapse" => $this->addSelectBox(MCI_Footnotes_Settings::C_BOOL_REFERENCE_CONTAINER_COLLAPSE, $l_arr_Enabled),
+
+ "label-symbol" => $this->addLabel(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_BACKLINK_SYMBOL_ENABLE, __("Display a backlink symbol", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
+ "symbol" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_BACKLINK_SYMBOL_ENABLE, $l_arr_Enabled),
+
+ "label-startpage" => $this->addLabel(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_START_PAGE_ENABLE, __("Display on start page too", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
+ "startpage" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_START_PAGE_ENABLE, $l_arr_Enabled),
+
+ "label-3column" => $this->addLabel(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_3COLUMN_LAYOUT_ENABLE, __("Three-column layout", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
+ "3column" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_3COLUMN_LAYOUT_ENABLE, $l_arr_Enabled),
+
+ "label-switch" => $this->addLabel(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_BACKLINK_SYMBOL_SWITCH, __("Symbol appended, not prepended", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
+ "switch" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_BACKLINK_SYMBOL_SWITCH, $l_arr_Enabled),
"label-position" => $this->addLabel(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_POSITION, __("Where shall the reference container appear", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
"position" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_REFERENCE_CONTAINER_POSITION, $l_arr_Positions)
@@ -247,7 +264,7 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
* @since 1.5.0
*/
public function Other() {
- // options for the Footnotes to be replaced in excerpt
+ // options for Yes/No select box:
$l_arr_Enabled = array(
"yes" => __("Yes", MCI_Footnotes_Config::C_STR_PLUGIN_NAME),
"no" => __("No", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)
@@ -275,11 +292,19 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
* @since 1.5.0
*/
public function Superscript() {
+ // options for Yes/No select box:
+ $l_arr_Enabled = array(
+ "yes" => __("Yes", MCI_Footnotes_Config::C_STR_PLUGIN_NAME),
+ "no" => __("No", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)
+ );
// load template file
$l_obj_Template = new MCI_Footnotes_Template(MCI_Footnotes_Template::C_STR_DASHBOARD, "customize-superscript");
// replace all placeholders
$l_obj_Template->replace(
array(
+ "label-superscript" => $this->addLabel(MCI_Footnotes_Settings::C_STR_FOOTNOTES_REFERRER_SUPERSCRIPT_TAGS, __("Enable superscript footnote referrers", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
+ "superscript" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_FOOTNOTES_REFERRER_SUPERSCRIPT_TAGS, $l_arr_Enabled),
+
"label-before" => $this->addLabel(MCI_Footnotes_Settings::C_STR_FOOTNOTES_STYLING_BEFORE, __("Before Footnotes index", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
"before" => $this->addTextBox(MCI_Footnotes_Settings::C_STR_FOOTNOTES_STYLING_BEFORE),
@@ -298,7 +323,7 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
* @since 1.5.2
*/
public function MouseOverBox() {
- // options for the Footnotes to be replaced in excerpt
+ // options for Yes/No select box:
$l_arr_Enabled = array(
"yes" => __("Yes", MCI_Footnotes_Config::C_STR_PLUGIN_NAME),
"no" => __("No", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)
@@ -331,6 +356,9 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
"label-excerpt-length" => $this->addLabel(MCI_Footnotes_Settings::C_INT_FOOTNOTES_MOUSE_OVER_BOX_EXCERPT_LENGTH, __("Maximum characters for the excerpt", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
"excerpt-length" => $this->addTextBox(MCI_Footnotes_Settings::C_INT_FOOTNOTES_MOUSE_OVER_BOX_EXCERPT_LENGTH),
+ "label-readon" => $this->addLabel(MCI_Footnotes_Settings::C_STR_FOOTNOTES_TOOLTIP_READON_LABEL, __("‘Read on’ button label", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
+ "readon" => $this->addTextBox(MCI_Footnotes_Settings::C_STR_FOOTNOTES_TOOLTIP_READON_LABEL),
+
"label-position" => $this->addLabel(MCI_Footnotes_Settings::C_STR_FOOTNOTES_MOUSE_OVER_BOX_POSITION, __("Position", MCI_Footnotes_Config::C_STR_PLUGIN_NAME)),
"position" => $this->addSelectBox(MCI_Footnotes_Settings::C_STR_FOOTNOTES_MOUSE_OVER_BOX_POSITION, $l_arr_Position),
@@ -383,8 +411,10 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
* @since 1.5.0
*
* Edited heading for v2.0.4
- * The former 'hyperlink arrow' became 'prepended arrow' in v2.0.3 after
- * a user complaint about missing backlinking semantics of the footnote number.
+ *
+ * The former 'hyperlink arrow', incompatible with combined identical footnotes,
+ * became 'prepended arrow' in v2.0.3 after a user complaint about missing backlinking semantics
+ * of the footnote number.
*/
public function HyperlinkArrow() {
// load template file
@@ -82,7 +85,7 @@ class MCI_Footnotes_Layout_Settings extends MCI_Footnotes_LayoutEngine {
protected function getMetaBoxes() {
return array(
- // Change string "%s styling" to "Footnotes styling":
+ // Change string "%s styling" to "Footnotes styling" to fix layout in WPv5.5:
$this->addMetaBox("settings", "styling", __("Footnotes styling", MCI_Footnotes_Config::C_STR_PLUGIN_NAME), "Styling"),
$this->addMetaBox("settings", "reference-container", __("References Container", MCI_Footnotes_Config::C_STR_PLUGIN_NAME), "ReferenceContainer"),